@@ -244,7 +244,7 @@ class SMSTradeAPI(SMSTradeAPIBase):
         if self.count:
             request_params['count'] = 1
         if self.reports:
-            request_params['dir'] = 1
+            request_params['dlr'] = 1
         if self.response and self.route == ROUTE_BASIC:
             request_params['response'] = 1
         return request_params
@@ -617,7 +617,7 @@ def send_sms(cmdline=None):
         '--count', action='store_const', const=True,
         help='enable output of message count')
     parser.add_argument(
-        '--dir', action='store_const', const=True,
+        '--dlr', action='store_const', const=True,
         dest='reports',
         help='enable delivery reports')
     parser.add_argument(
